@@ -12,11 +12,11 @@ from .scpi_exceptions import ScpiTransportException
 class ScpiTcpIpTransport(ScpiTransportBase):
     DEFAULT_PORT: int = 5025
 
-    transport_name = 'ScpiTcpIpTransport'
-    transport_info = 'TCP/IP SCPI Transport'
-    transport_type = 'TCP/IP'
+    _transport_class = 'ScpiTcpIpTransport'
+    _transport_info = 'TCP/IP SCPI Transport'
+    _transport_type = 'TCP/IP'
 
-    sock: Optional[socket.socket] = None
+    _sock: Optional[socket.socket] = None
 
     @classmethod
     def discover(cls,
@@ -57,7 +57,7 @@ class ScpiTcpIpTransport(ScpiTransportBase):
 
         return [ScpiResource(transport=ScpiTcpIpTransport,
                              location=f'dnssd:{service.name}',
-                             address=f'{service.parsed_addresses()[0]}:{service.port}',
+                             address=(service.parsed_addresses()[0], int(service.port)),
                              name=service.get_name(),
                              manufacturer=service.properties[b'Manufacturer'].decode(
                                  'utf-8') if b'Manufacturer' in service.properties else None,
@@ -69,27 +69,56 @@ class ScpiTcpIpTransport(ScpiTransportBase):
                              ) for service in listener.services.values()
                 if any([pattern.fullmatch(service.get_name()) for pattern in patterns])]
 
+    @classmethod
+    def from_resource_name(cls, resource_name: str) -> Optional[ScpiResource]:
+        m = re.match((
+            r'^(?P<prefix>(?P<type>TCPIP)(?P<board>\d+)?)'
+            r'::(?P<host_address>.+)'
+            r'::(?P<port>([0-9]+))'
+            r'(::(?P<suffix>SOCKET))?$'
+        ), resource_name, re.IGNORECASE)
+
+        if m is None:
+            # Does not match the regex
+            return None
+
+        groupdict = m.groupdict()
+
+        return ScpiResource(
+            transport=ScpiTcpIpTransport,
+            address=(groupdict["host_address"], int(groupdict["port"]))
+        )
+
+    @classmethod
+    def to_resource_name(cls, resource: ScpiResource) -> str:
+        address = resource.address
+        return f'TCPIP::{address[0]}::{address[1]}::SOCKET'
+
     def __init__(self, address: str, timeout: float = 5, **kwargs):
         super().__init__(**kwargs)
-        self.logger = logging.getLogger(__name__)
-        self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        self._logger = logging.getLogger(__name__)
+        self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
-        self.sock.settimeout(timeout)
-        self.sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+        self._sock.settimeout(timeout)
+        self._sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
 
         # Get hostname and port
+        if isinstance(address, tuple):
+            # Convert from tuple to string first
+            address = f'{address[0]}:{address[1]}'
+
         addr = urlparse('//' + address)
         if (addr.hostname is None):
             raise ScpiTransportException(f'{address} is not a valid hostname')
 
         try:
             # Try to connect
-            self.sock.connect((addr.hostname,
-                               addr.port if addr.port is not None else self.DEFAULT_PORT))
+            self._sock.connect((addr.hostname,
+                                addr.port if addr.port is not None else self.DEFAULT_PORT))
 
             # Make a file interface for easier handling
-            self.io = self.sock.makefile('rwb', buffering=0)
-            self.io.flush()
+            self._io = self._sock.makefile('rwb', buffering=0)
+            self._io.flush()
         except OSError as e:
             raise ScpiTransportException(e) from e
 
@@ -98,6 +127,6 @@ class ScpiTcpIpTransport(ScpiTransportBase):
         super().close()
 
         # Close socket as well
-        self.sock.shutdown(socket.SHUT_RDWR)
-        self.sock.close()
-        self.sock = None
+        self._sock.shutdown(socket.SHUT_RDWR)
+        self._sock.close()
+        self._sock = None
