@@ -201,8 +201,6 @@ class ScpiString(ScpiTypeBase):
         string = ""
         while 1:
             chunk = transport.readline()
-            # TODO: double quotes
-
             quotes += chunk.count('"')
             string += chunk + '\r\n'
 
@@ -210,6 +208,8 @@ class ScpiString(ScpiTypeBase):
                 break
 
         string = string.strip('\r\n\t"')
+        string = string.replace('""', '"')
+
         return ScpiString(string)
 
 
